/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cocoon.pipeline.caching;

import java.io.IOException;
import java.io.OutputStream;

import org.apache.cocoon.pipeline.util.StringRepresentation;

public class CompleteCacheValue implements CacheValue {

    private final byte[] content;
    private final CacheKey cacheKey;

    public CompleteCacheValue(byte[] content, CacheKey cacheKey) {
        super();

        this.content = content;
        this.cacheKey = cacheKey;
    }

    /**
     * {@inheritDoc}
     * 
     * @see org.apache.cocoon.pipeline.caching.CacheValue#isValid(org.apache.cocoon.pipeline.caching.CacheKey)
     */
    public boolean isValid(CacheKey cacheKey) {
        return this.cacheKey != null && this.cacheKey.isValid(cacheKey);
    }

    /**
     * {@inheritDoc}
     * 
     * @see org.apache.cocoon.pipeline.caching.CacheValue#writeTo(java.io.OutputStream)
     */
    public void writeTo(OutputStream outputStream) throws IOException {
        outputStream.write(this.content);
    }

    @Override
    public String toString() {
        return StringRepresentation.buildString(this, "content.length=" + this.content.length, "cacheKey="
                + this.cacheKey);
    }
}
