/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cocoon.pipeline.component.sax;

import java.io.ByteArrayInputStream;

import org.apache.cocoon.pipeline.component.Starter;
import org.apache.cocoon.pipeline.util.StringRepresentation;
import org.apache.cocoon.pipeline.util.XMLUtils;

public class StringGenerator extends AbstractXMLProducer implements Starter {

    private String xmlString;

    public StringGenerator(String xmlString) {
        super();
        if (xmlString == null) {
            throw new IllegalArgumentException("An XML string has to be passed.");
        }

        this.xmlString = xmlString;
    }

    /**
     * {@inheritDoc}
     * 
     * @see org.apache.cocoon.pipeline.component.Starter#execute()
     */
    public void execute() {
        XMLUtils.toSax(new ByteArrayInputStream(this.xmlString.getBytes()), this.getXMLConsumer());
    }

    @Override
    public String toString() {
        return StringRepresentation.buildString(this, "xmlString=" + this.xmlString);
    }
}
