/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.cocoon.pipeline.component.sax;

import org.xml.sax.Attributes;
import org.xml.sax.ContentHandler;
import org.xml.sax.Locator;
import org.xml.sax.SAXException;
import org.xml.sax.ext.LexicalHandler;

public class XMLConsumerAdapter implements XMLConsumer {

    protected ContentHandler contentHandler;
    protected LexicalHandler lexicalHandler;
    protected XMLConsumer consumer;

    public XMLConsumerAdapter() {
    }

    public XMLConsumerAdapter(ContentHandler contentHandler, LexicalHandler lexicalHandler) {
        super();
        this.contentHandler = contentHandler;
        this.lexicalHandler = lexicalHandler;
    }

    public void setConsumer(XMLConsumer consumer) {
        this.consumer = consumer;
        this.setContentHandler(consumer);
        this.setLexicalHandler(consumer);
    }

    public void setContentHandler(ContentHandler contentHandler) {
        this.contentHandler = contentHandler;
    }

    public void setLexicalHandler(LexicalHandler lexicalHandler) {
        this.lexicalHandler = lexicalHandler;
    }

    public void characters(char[] ch, int start, int length) throws SAXException {
        this.contentHandler.characters(ch, start, length);
    }

    public void comment(char[] ch, int start, int length) throws SAXException {
        this.lexicalHandler.comment(ch, start, length);
    }

    public void endCDATA() throws SAXException {
        this.lexicalHandler.endCDATA();
    }

    public void endDocument() throws SAXException {
        this.contentHandler.endDocument();
    }

    public void endDTD() throws SAXException {
        this.lexicalHandler.endDTD();
    }

    public void endElement(String uri, String localName, String name) throws SAXException {
        this.contentHandler.endElement(uri, localName, name);
    }

    public void endEntity(String name) throws SAXException {
        this.lexicalHandler.endEntity(name);
    }

    public void endPrefixMapping(String prefix) throws SAXException {
        this.contentHandler.endPrefixMapping(prefix);
    }

    public void ignorableWhitespace(char[] ch, int start, int length) throws SAXException {
        this.contentHandler.ignorableWhitespace(ch, start, length);
    }

    public void processingInstruction(String target, String data) throws SAXException {
        this.contentHandler.processingInstruction(target, data);
    }

    public void setDocumentLocator(Locator locator) {
        this.contentHandler.setDocumentLocator(locator);
    }

    public void skippedEntity(String name) throws SAXException {
        this.contentHandler.skippedEntity(name);
    }

    public void startCDATA() throws SAXException {
        this.lexicalHandler.startCDATA();
    }

    public void startDocument() throws SAXException {
        this.contentHandler.startDocument();
    }

    public void startDTD(String name, String publicId, String systemId) throws SAXException {
        this.lexicalHandler.startDTD(name, publicId, systemId);
    }

    public void startElement(String uri, String localName, String name, Attributes atts) throws SAXException {
        this.contentHandler.startElement(uri, localName, name, atts);
    }

    public void startEntity(String name) throws SAXException {
        this.lexicalHandler.startEntity(name);
    }

    public void startPrefixMapping(String prefix, String uri) throws SAXException {
        this.contentHandler.startPrefixMapping(prefix, uri);
    }
}
