/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cocoon.pipeline.util;

import org.apache.cocoon.pipeline.component.sax.XMLConsumer;
import org.xml.sax.Attributes;
import org.xml.sax.Locator;
import org.xml.sax.SAXException;

/**
 * An {@link XMLConsumer} that does swallows all incoming SAX events.
 */
public class NullXMLConsumer implements XMLConsumer {

    public void characters(char[] ch, int start, int length) throws SAXException {
        // do nothing
    }

    public void endDocument() throws SAXException {
        // do nothing
    }

    public void endElement(String uri, String localName, String name) throws SAXException {
        // do nothing
    }

    public void endPrefixMapping(String prefix) throws SAXException {
        // do nothing
    }

    public void ignorableWhitespace(char[] ch, int start, int length) throws SAXException {
        // do nothing
    }

    public void processingInstruction(String target, String data) throws SAXException {
        // do nothing
    }

    public void setDocumentLocator(Locator locator) {
        // do nothing
    }

    public void skippedEntity(String name) throws SAXException {
        // do nothing
    }

    public void startDocument() throws SAXException {
        // do nothing
    }

    public void startElement(String uri, String localName, String name, Attributes atts) throws SAXException {
        // do nothing
    }

    public void startPrefixMapping(String prefix, String uri) throws SAXException {
        // do nothing
    }

    public void comment(char[] ch, int start, int length) throws SAXException {
        // do nothing
    }

    public void endCDATA() throws SAXException {
        // do nothing
    }

    public void endDTD() throws SAXException {
        // do nothing
    }

    public void endEntity(String name) throws SAXException {
        // do nothing
    }

    public void startCDATA() throws SAXException {
        // do nothing
    }

    public void startDTD(String name, String publicId, String systemId) throws SAXException {
        // do nothing
    }

    public void startEntity(String name) throws SAXException {
        // do nothing
    }
}