/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cocoon.pipeline;

import java.io.ByteArrayOutputStream;

import junit.framework.TestCase;

import org.apache.cocoon.pipeline.component.sax.FileReaderComponent;
import org.apache.cocoon.pipeline.component.sax.StringGenerator;
import org.apache.cocoon.pipeline.component.sax.XMLSerializer;
import org.apache.cocoon.pipeline.component.sax.XSLTTransformer;
import org.custommonkey.xmlunit.Diff;

public class PipelineTest extends TestCase {

    /**
     * A very simple pipeline that only uses a reader.
     */
    public void testPipelineWithReader() throws Exception {
        Pipeline pipeline = new NonCachingPipeline();
        pipeline.addComponent(new FileReaderComponent(this.getClass().getResource("/test.xml")));
        pipeline.setup(System.out);
        pipeline.execute();
    }

    /**
     * A pipeline that performs a simple transformation: generator -&gt; transformer -&gt; serializer
     */
    public void testPipelineWithTransformer() throws Exception {
        Pipeline pipeline = new NonCachingPipeline();
        pipeline.addComponent(new StringGenerator("<x></x>"));
        pipeline.addComponent(new XSLTTransformer(this.getClass().getResource("/test.xslt")));
        pipeline.addComponent(new XMLSerializer());

        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        pipeline.setup(baos);
        pipeline.execute();

        Diff diff = new Diff("<?xml version=\"1.0\" encoding=\"UTF-8\"?><p></p>", new String(baos.toByteArray()));
        assertTrue("XSL transformation didn't work as expected " + diff, diff.identical());
    }
}
